@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -358,6 +358,7 @@ class DistanceCalculatorServiceClient(metaclass=DistanceCalculatorServiceClientM
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def calculate_distance(self,
@@ -374,7 +375,6 @@ class DistanceCalculatorServiceClient(metaclass=DistanceCalculatorServiceClientM
         a series of points. If speed is specified, expected
         duration of the voyage will also be returned.
 
-
         .. code-block:: python
 
             from oceanbolt.com import distancecalculator_v3
@@ -432,6 +432,72 @@ class DistanceCalculatorServiceClient(metaclass=DistanceCalculatorServiceClientM
         # Done; return the response.
         return response
 
+    def batch_calculate_distance(self,
+            request: Union[service.BatchDistanceRequest, dict] = None,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.BatchDistanceResponse:
+        r"""
+
+        .. code-block:: python
+
+            from oceanbolt.com import distancecalculator_v3
+
+            def sample_batch_calculate_distance():
+                # Create a client
+                client = distancecalculator_v3.DistanceCalculatorServiceClient()
+
+                # Initialize request argument(s)
+                request = distancecalculator_v3.BatchDistanceRequest(
+                )
+
+                # Make the request
+                response = client.batch_calculate_distance(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.distancecalculator_v3.types.BatchDistanceRequest, dict]):
+                The request object. Request object for
+                BatchCalculateDistance method
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.distancecalculator_v3.types.BatchDistanceResponse:
+                Response object for
+                BatchCalculateDistance method
+
+        """
+        # Create or coerce a protobuf request object.
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.BatchDistanceRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.BatchDistanceRequest):
+            request = service.BatchDistanceRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.batch_calculate_distance]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def __enter__(self):
         return self
 
@@ -447,6 +513,9 @@ class DistanceCalculatorServiceClient(metaclass=DistanceCalculatorServiceClientM
 
 
 
+
+
+
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
