@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,8 @@
 # limitations under the License.
 #
 from .service import (
+    BatchDistanceRequest,
+    BatchDistanceResponse,
     DistanceRequest,
     DistanceResponse,
     Leg,
@@ -22,6 +24,8 @@ from .service import (
 )
 
 __all__ = (
+    'BatchDistanceRequest',
+    'BatchDistanceResponse',
     'DistanceRequest',
     'DistanceResponse',
     'Leg',
