@@ -19,17 +19,20 @@ from oceanbolt.com.entities_v3.services.entity_service.async_client import Entit
 
 from oceanbolt.com.entities_v3.types.service import Commodity
 from oceanbolt.com.entities_v3.types.service import Country
-from oceanbolt.com.entities_v3.types.service import EmptyParams
+from oceanbolt.com.entities_v3.types.service import ListCommoditiesRequest
 from oceanbolt.com.entities_v3.types.service import ListCommoditiesResponse
 from oceanbolt.com.entities_v3.types.service import ListCountriesRequest
 from oceanbolt.com.entities_v3.types.service import ListCountriesResponse
+from oceanbolt.com.entities_v3.types.service import ListPortsRequest
 from oceanbolt.com.entities_v3.types.service import ListPortsResponse
 from oceanbolt.com.entities_v3.types.service import ListRegionsRequest
 from oceanbolt.com.entities_v3.types.service import ListRegionsResponse
 from oceanbolt.com.entities_v3.types.service import ListRegionsWithPolygonResponse
+from oceanbolt.com.entities_v3.types.service import ListSegmentsRequest
 from oceanbolt.com.entities_v3.types.service import ListSegmentsResponse
 from oceanbolt.com.entities_v3.types.service import ListTonnageZonesResponse
 from oceanbolt.com.entities_v3.types.service import ListTonnageZonesWithPolygonsResponse
+from oceanbolt.com.entities_v3.types.service import ListZonesRequest
 from oceanbolt.com.entities_v3.types.service import Polygon
 from oceanbolt.com.entities_v3.types.service import Port
 from oceanbolt.com.entities_v3.types.service import Region
@@ -46,17 +49,20 @@ __all__ = ('EntityServiceClient',
     'EntityServiceAsyncClient',
     'Commodity',
     'Country',
-    'EmptyParams',
+    'ListCommoditiesRequest',
     'ListCommoditiesResponse',
     'ListCountriesRequest',
     'ListCountriesResponse',
+    'ListPortsRequest',
     'ListPortsResponse',
     'ListRegionsRequest',
     'ListRegionsResponse',
     'ListRegionsWithPolygonResponse',
+    'ListSegmentsRequest',
     'ListSegmentsResponse',
     'ListTonnageZonesResponse',
     'ListTonnageZonesWithPolygonsResponse',
+    'ListZonesRequest',
     'Polygon',
     'Port',
     'Region',
