@@ -227,14 +227,14 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
 
     @property
     def list_segments(self) -> Callable[
-            [service.EmptyParams],
+            [service.ListSegmentsRequest],
             service.ListSegmentsResponse]:
         r"""Return a callable for the list segments method over gRPC.
 
         ListSegments retrieves all available vessel segments
 
         Returns:
-            Callable[[~.EmptyParams],
+            Callable[[~.ListSegmentsRequest],
                     ~.ListSegmentsResponse]:
                 A function that, when called, will call the underlying RPC
                 on the server.
@@ -246,21 +246,21 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         if 'list_segments' not in self._stubs:
             self._stubs['list_segments'] = self.grpc_channel.unary_unary(
                 '/oceanbolt.com.entities.v3.EntityService/ListSegments',
-                request_serializer=service.EmptyParams.serialize,
+                request_serializer=service.ListSegmentsRequest.serialize,
                 response_deserializer=service.ListSegmentsResponse.deserialize,
             )
         return self._stubs['list_segments']
 
     @property
     def list_zones(self) -> Callable[
-            [service.EmptyParams],
+            [service.ListZonesRequest],
             service.ListTonnageZonesResponse]:
         r"""Return a callable for the list zones method over gRPC.
 
         ListZones retrieves all zones
 
         Returns:
-            Callable[[~.EmptyParams],
+            Callable[[~.ListZonesRequest],
                     ~.ListTonnageZonesResponse]:
                 A function that, when called, will call the underlying RPC
                 on the server.
@@ -272,14 +272,14 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         if 'list_zones' not in self._stubs:
             self._stubs['list_zones'] = self.grpc_channel.unary_unary(
                 '/oceanbolt.com.entities.v3.EntityService/ListZones',
-                request_serializer=service.EmptyParams.serialize,
+                request_serializer=service.ListZonesRequest.serialize,
                 response_deserializer=service.ListTonnageZonesResponse.deserialize,
             )
         return self._stubs['list_zones']
 
     @property
     def list_zones_with_polygons(self) -> Callable[
-            [service.EmptyParams],
+            [service.ListZonesRequest],
             service.ListTonnageZonesWithPolygonsResponse]:
         r"""Return a callable for the list zones with polygons method over gRPC.
 
@@ -287,7 +287,7 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         Polygons
 
         Returns:
-            Callable[[~.EmptyParams],
+            Callable[[~.ListZonesRequest],
                     ~.ListTonnageZonesWithPolygonsResponse]:
                 A function that, when called, will call the underlying RPC
                 on the server.
@@ -299,21 +299,21 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         if 'list_zones_with_polygons' not in self._stubs:
             self._stubs['list_zones_with_polygons'] = self.grpc_channel.unary_unary(
                 '/oceanbolt.com.entities.v3.EntityService/ListZonesWithPolygons',
-                request_serializer=service.EmptyParams.serialize,
+                request_serializer=service.ListZonesRequest.serialize,
                 response_deserializer=service.ListTonnageZonesWithPolygonsResponse.deserialize,
             )
         return self._stubs['list_zones_with_polygons']
 
     @property
     def list_regions(self) -> Callable[
-            [service.EmptyParams],
+            [service.ListRegionsRequest],
             service.ListRegionsResponse]:
         r"""Return a callable for the list regions method over gRPC.
 
         ListRegions retrives all regions
 
         Returns:
-            Callable[[~.EmptyParams],
+            Callable[[~.ListRegionsRequest],
                     ~.ListRegionsResponse]:
                 A function that, when called, will call the underlying RPC
                 on the server.
@@ -325,21 +325,21 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         if 'list_regions' not in self._stubs:
             self._stubs['list_regions'] = self.grpc_channel.unary_unary(
                 '/oceanbolt.com.entities.v3.EntityService/ListRegions',
-                request_serializer=service.EmptyParams.serialize,
+                request_serializer=service.ListRegionsRequest.serialize,
                 response_deserializer=service.ListRegionsResponse.deserialize,
             )
         return self._stubs['list_regions']
 
     @property
     def list_commodities(self) -> Callable[
-            [service.EmptyParams],
+            [service.ListCommoditiesRequest],
             service.ListCommoditiesResponse]:
         r"""Return a callable for the list commodities method over gRPC.
 
         ListCommodities retrives all commodities
 
         Returns:
-            Callable[[~.EmptyParams],
+            Callable[[~.ListCommoditiesRequest],
                     ~.ListCommoditiesResponse]:
                 A function that, when called, will call the underlying RPC
                 on the server.
@@ -351,21 +351,21 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         if 'list_commodities' not in self._stubs:
             self._stubs['list_commodities'] = self.grpc_channel.unary_unary(
                 '/oceanbolt.com.entities.v3.EntityService/ListCommodities',
-                request_serializer=service.EmptyParams.serialize,
+                request_serializer=service.ListCommoditiesRequest.serialize,
                 response_deserializer=service.ListCommoditiesResponse.deserialize,
             )
         return self._stubs['list_commodities']
 
     @property
     def list_countries(self) -> Callable[
-            [service.EmptyParams],
+            [service.ListCountriesRequest],
             service.ListCountriesResponse]:
         r"""Return a callable for the list countries method over gRPC.
 
         ListCountries retrives all countries
 
         Returns:
-            Callable[[~.EmptyParams],
+            Callable[[~.ListCountriesRequest],
                     ~.ListCountriesResponse]:
                 A function that, when called, will call the underlying RPC
                 on the server.
@@ -377,14 +377,14 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         if 'list_countries' not in self._stubs:
             self._stubs['list_countries'] = self.grpc_channel.unary_unary(
                 '/oceanbolt.com.entities.v3.EntityService/ListCountries',
-                request_serializer=service.EmptyParams.serialize,
+                request_serializer=service.ListCountriesRequest.serialize,
                 response_deserializer=service.ListCountriesResponse.deserialize,
             )
         return self._stubs['list_countries']
 
     @property
     def list_regions_with_polygons(self) -> Callable[
-            [service.EmptyParams],
+            [service.ListRegionsRequest],
             service.ListRegionsWithPolygonResponse]:
         r"""Return a callable for the list regions with polygons method over gRPC.
 
@@ -392,7 +392,7 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         polygons
 
         Returns:
-            Callable[[~.EmptyParams],
+            Callable[[~.ListRegionsRequest],
                     ~.ListRegionsWithPolygonResponse]:
                 A function that, when called, will call the underlying RPC
                 on the server.
@@ -404,21 +404,21 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         if 'list_regions_with_polygons' not in self._stubs:
             self._stubs['list_regions_with_polygons'] = self.grpc_channel.unary_unary(
                 '/oceanbolt.com.entities.v3.EntityService/ListRegionsWithPolygons',
-                request_serializer=service.EmptyParams.serialize,
+                request_serializer=service.ListRegionsRequest.serialize,
                 response_deserializer=service.ListRegionsWithPolygonResponse.deserialize,
             )
         return self._stubs['list_regions_with_polygons']
 
     @property
     def list_ports(self) -> Callable[
-            [service.EmptyParams],
+            [service.ListPortsRequest],
             service.ListPortsResponse]:
         r"""Return a callable for the list ports method over gRPC.
 
         ListPorts retrieves all ports
 
         Returns:
-            Callable[[~.EmptyParams],
+            Callable[[~.ListPortsRequest],
                     ~.ListPortsResponse]:
                 A function that, when called, will call the underlying RPC
                 on the server.
@@ -430,7 +430,7 @@ class EntityServiceGrpcTransport(EntityServiceTransport):
         if 'list_ports' not in self._stubs:
             self._stubs['list_ports'] = self.grpc_channel.unary_unary(
                 '/oceanbolt.com.entities.v3.EntityService/ListPorts',
-                request_serializer=service.EmptyParams.serialize,
+                request_serializer=service.ListPortsRequest.serialize,
                 response_deserializer=service.ListPortsResponse.deserialize,
             )
         return self._stubs['list_ports']
