@@ -31,7 +31,7 @@ try:
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.protobuf import wrappers_pb2  # type: ignore
+from oceanbolt.com.polygonmanagement_v3.types import resources
 from oceanbolt.com.polygonmanagement_v3.types import service
 from .transports.base import PolygonManagementServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import PolygonManagementServiceGrpcAsyncIOTransport
@@ -39,7 +39,9 @@ from .client import PolygonManagementServiceClient
 
 
 class PolygonManagementServiceAsyncClient:
-    """LayerManagement provides service to manage layers for clients"""
+    """PolygonManagementService provides service to manage layers
+    and polygons for clients
+    """
 
     _client: PolygonManagementServiceClient
 
@@ -182,12 +184,12 @@ class PolygonManagementServiceAsyncClient:
         )
 
     async def list_layers(self,
-            request: Union[service.EmptyParams, dict] = None,
+            request: Union[service.ListLayersRequest, dict] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Layers:
+            ) -> service.ListLayersResponse:
         r"""ListLayers lists layers for the current user
 
         .. code-block:: python
@@ -199,7 +201,7 @@ class PolygonManagementServiceAsyncClient:
                 client = polygonmanagement_v3.PolygonManagementServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = polygonmanagement_v3.EmptyParams(
+                request = polygonmanagement_v3.ListLayersRequest(
                 )
 
                 # Make the request
@@ -209,8 +211,9 @@ class PolygonManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.polygonmanagement_v3.types.EmptyParams, dict]):
-                The request object.
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.ListLayersRequest, dict]):
+                The request object. LayerManagement requests and
+                responses
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -218,11 +221,11 @@ class PolygonManagementServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            oceanbolt.com.polygonmanagement_v3.types.Layers:
+            oceanbolt.com.polygonmanagement_v3.types.ListLayersResponse:
 
         """
         # Create or coerce a protobuf request object.
-        request = service.EmptyParams(request)
+        request = service.ListLayersRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -249,7 +252,7 @@ class PolygonManagementServiceAsyncClient:
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Layer:
+            ) -> resources.Layer:
         r"""CreateLayer creates new layer for the current user
 
         .. code-block:: python
@@ -311,7 +314,7 @@ class PolygonManagementServiceAsyncClient:
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.EmptyResponse:
+            ) -> None:
         r"""DeleteLayer deletes layer for the current user
 
         .. code-block:: python
@@ -327,10 +330,7 @@ class PolygonManagementServiceAsyncClient:
                 )
 
                 # Make the request
-                response = await client.delete_layer(request=request)
-
-                # Handle the response
-                print(response)
+                await client.delete_layer(request=request)
 
         Args:
             request (Union[oceanbolt.com.polygonmanagement_v3.types.DeleteLayerRequest, dict]):
@@ -340,10 +340,6 @@ class PolygonManagementServiceAsyncClient:
             timeout (float): The timeout for this request.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
-
-        Returns:
-            oceanbolt.com.polygonmanagement_v3.types.EmptyResponse:
-
         """
         # Create or coerce a protobuf request object.
         request = service.DeleteLayerRequest(request)
@@ -364,6 +360,74 @@ class PolygonManagementServiceAsyncClient:
             )),
         )
 
+        # Send the request.
+        await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+    async def copy_layer(self,
+            request: Union[service.CopyLayerRequest, dict] = None,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> resources.Layer:
+        r"""CopyLayer creates a copy of the existing layer for
+        the current user
+
+        .. code-block:: python
+
+            from oceanbolt.com import polygonmanagement_v3
+
+            async def sample_copy_layer():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.CopyLayerRequest(
+                )
+
+                # Make the request
+                response = await client.copy_layer(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.CopyLayerRequest, dict]):
+                The request object.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.polygonmanagement_v3.types.Layer:
+
+        """
+        # Create or coerce a protobuf request object.
+        request = service.CopyLayerRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.copy_layer,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((
+                ("layer_id", request.layer_id),
+            )),
+        )
+
         # Send the request.
         response = await rpc(
             request,
@@ -381,7 +445,7 @@ class PolygonManagementServiceAsyncClient:
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Layer:
+            ) -> resources.Layer:
         r"""GetLayer gets fleed by layer id for the current user
 
         .. code-block:: python
@@ -445,85 +509,13 @@ class PolygonManagementServiceAsyncClient:
         # Done; return the response.
         return response
 
-    async def rename_layer(self,
-            request: Union[service.RenameLayerRequest, dict] = None,
-            *,
-            retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
-            metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Layer:
-        r"""RenameLayer changes the name of the layer for the
-        current user
-
-        .. code-block:: python
-
-            from oceanbolt.com import polygonmanagement_v3
-
-            async def sample_rename_layer():
-                # Create a client
-                client = polygonmanagement_v3.PolygonManagementServiceAsyncClient()
-
-                # Initialize request argument(s)
-                request = polygonmanagement_v3.RenameLayerRequest(
-                )
-
-                # Make the request
-                response = await client.rename_layer(request=request)
-
-                # Handle the response
-                print(response)
-
-        Args:
-            request (Union[oceanbolt.com.polygonmanagement_v3.types.RenameLayerRequest, dict]):
-                The request object.  LayerManagement requests ans
-                responses
-            retry (google.api_core.retry.Retry): Designation of what errors, if any,
-                should be retried.
-            timeout (float): The timeout for this request.
-            metadata (Sequence[Tuple[str, str]]): Strings which should be
-                sent along with the request as metadata.
-
-        Returns:
-            oceanbolt.com.polygonmanagement_v3.types.Layer:
-
-        """
-        # Create or coerce a protobuf request object.
-        request = service.RenameLayerRequest(request)
-
-        # Wrap the RPC method; this adds retry and timeout information,
-        # and friendly error handling.
-        rpc = gapic_v1.method_async.wrap_method(
-            self._client._transport.rename_layer,
-            default_timeout=None,
-            client_info=DEFAULT_CLIENT_INFO,
-        )
-
-        # Certain fields should be provided within the metadata header;
-        # add these here.
-        metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((
-                ("layer_id", request.layer_id),
-            )),
-        )
-
-        # Send the request.
-        response = await rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
-        )
-
-        # Done; return the response.
-        return response
-
     async def share_layer(self,
             request: Union[service.ShareLayerRequest, dict] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Layer:
+            ) -> resources.Layer:
         r"""Sets the shared status of the layer to be either
         shared/not shared
 
@@ -594,7 +586,7 @@ class PolygonManagementServiceAsyncClient:
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Layer:
+            ) -> resources.Layer:
         r"""Sets the shared status of the layer to be either
         shared/not shared
 
@@ -665,9 +657,8 @@ class PolygonManagementServiceAsyncClient:
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Polygons:
-        r"""GetLayerPolygons gets layer polygons for the current
-        user
+            ) -> service.ListPolygonsResponse:
+        r"""GetLayerPolygons gets polygons for a given layer
 
         .. code-block:: python
 
@@ -697,7 +688,7 @@ class PolygonManagementServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            oceanbolt.com.polygonmanagement_v3.types.Polygons:
+            oceanbolt.com.polygonmanagement_v3.types.ListPolygonsResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -736,8 +727,8 @@ class PolygonManagementServiceAsyncClient:
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Polygon:
-        r"""AddPolygon adds new vessel to user's layer
+            ) -> resources.Polygon:
+        r"""AddPolygon adds new polygon to a layer
 
         .. code-block:: python
 
@@ -806,8 +797,8 @@ class PolygonManagementServiceAsyncClient:
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.Polygon:
-        r"""UpdatePolygon updates existing vessel to user's layer
+            ) -> resources.Polygon:
+        r"""UpdatePolygon updates a polygon in a given layer
 
         .. code-block:: python
 
@@ -877,8 +868,8 @@ class PolygonManagementServiceAsyncClient:
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.EmptyResponse:
-        r"""DeletePolygon removes vessel from user's layer
+            ) -> None:
+        r"""DeletePolygon removes a polygon from a given layer
 
         .. code-block:: python
 
@@ -893,10 +884,7 @@ class PolygonManagementServiceAsyncClient:
                 )
 
                 # Make the request
-                response = await client.delete_polygon(request=request)
-
-                # Handle the response
-                print(response)
+                await client.delete_polygon(request=request)
 
         Args:
             request (Union[oceanbolt.com.polygonmanagement_v3.types.DeletePolygonRequest, dict]):
@@ -906,10 +894,6 @@ class PolygonManagementServiceAsyncClient:
             timeout (float): The timeout for this request.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
-
-        Returns:
-            oceanbolt.com.polygonmanagement_v3.types.EmptyResponse:
-
         """
         # Create or coerce a protobuf request object.
         request = service.DeletePolygonRequest(request)
@@ -932,24 +916,21 @@ class PolygonManagementServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(
+        await rpc(
             request,
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        # Done; return the response.
-        return response
-
     async def batch_add_polygons(self,
-            request: Union[service.BatchPolygonsRequest, dict] = None,
+            request: Union[service.BatchAddPolygonsRequest, dict] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.EmptyResponse:
-        r"""
+            ) -> service.BatchAddPolygonsResponse:
+        r"""BatchAddPolygons adds a batch of polygons to a layer
 
         .. code-block:: python
 
@@ -960,7 +941,7 @@ class PolygonManagementServiceAsyncClient:
                 client = polygonmanagement_v3.PolygonManagementServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = polygonmanagement_v3.BatchPolygonsRequest(
+                request = polygonmanagement_v3.BatchAddPolygonsRequest(
                 )
 
                 # Make the request
@@ -970,7 +951,7 @@ class PolygonManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.polygonmanagement_v3.types.BatchPolygonsRequest, dict]):
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.BatchAddPolygonsRequest, dict]):
                 The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -979,11 +960,11 @@ class PolygonManagementServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            oceanbolt.com.polygonmanagement_v3.types.EmptyResponse:
+            oceanbolt.com.polygonmanagement_v3.types.BatchAddPolygonsResponse:
 
         """
         # Create or coerce a protobuf request object.
-        request = service.BatchPolygonsRequest(request)
+        request = service.BatchAddPolygonsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -1013,13 +994,14 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def replace_polygons(self,
-            request: Union[service.BatchPolygonsRequest, dict] = None,
+            request: Union[service.ReplacePolygonsRequest, dict] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.EmptyResponse:
-        r"""
+            ) -> None:
+        r"""ReplacePolygons replaces all existing polygons in a
+        layer with a new batch of polygons
 
         .. code-block:: python
 
@@ -1030,30 +1012,23 @@ class PolygonManagementServiceAsyncClient:
                 client = polygonmanagement_v3.PolygonManagementServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = polygonmanagement_v3.BatchPolygonsRequest(
+                request = polygonmanagement_v3.ReplacePolygonsRequest(
                 )
 
                 # Make the request
-                response = await client.replace_polygons(request=request)
-
-                # Handle the response
-                print(response)
+                await client.replace_polygons(request=request)
 
         Args:
-            request (Union[oceanbolt.com.polygonmanagement_v3.types.BatchPolygonsRequest, dict]):
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.ReplacePolygonsRequest, dict]):
                 The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
-
-        Returns:
-            oceanbolt.com.polygonmanagement_v3.types.EmptyResponse:
-
         """
         # Create or coerce a protobuf request object.
-        request = service.BatchPolygonsRequest(request)
+        request = service.ReplacePolygonsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -1072,24 +1047,21 @@ class PolygonManagementServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(
+        await rpc(
             request,
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        # Done; return the response.
-        return response
-
     async def drop_polygons(self,
             request: Union[service.DropPolygonsRequest, dict] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
-            ) -> service.EmptyResponse:
-        r"""
+            ) -> None:
+        r"""Drop polygons drops all polygons from a layer
 
         .. code-block:: python
 
@@ -1104,10 +1076,7 @@ class PolygonManagementServiceAsyncClient:
                 )
 
                 # Make the request
-                response = await client.drop_polygons(request=request)
-
-                # Handle the response
-                print(response)
+                await client.drop_polygons(request=request)
 
         Args:
             request (Union[oceanbolt.com.polygonmanagement_v3.types.DropPolygonsRequest, dict]):
@@ -1117,10 +1086,6 @@ class PolygonManagementServiceAsyncClient:
             timeout (float): The timeout for this request.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
-
-        Returns:
-            oceanbolt.com.polygonmanagement_v3.types.EmptyResponse:
-
         """
         # Create or coerce a protobuf request object.
         request = service.DropPolygonsRequest(request)
@@ -1142,16 +1107,13 @@ class PolygonManagementServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(
+        await rpc(
             request,
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        # Done; return the response.
-        return response
-
     async def __aenter__(self):
         return self
 
