@@ -13,46 +13,46 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from .resources import (
+    Layer,
+    Polygon,
+)
 from .service import (
     AddPolygonRequest,
-    BatchPolygonsRequest,
+    BatchAddPolygonsRequest,
+    BatchAddPolygonsResponse,
     CopyLayerRequest,
     CreateLayerRequest,
     DeleteLayerRequest,
     DeletePolygonRequest,
     DropPolygonsRequest,
-    EmptyParams,
-    EmptyResponse,
     GetLayerRequest,
-    Layer,
-    Layers,
+    ListLayersRequest,
+    ListLayersResponse,
     ListPolygonsRequest,
-    Polygon,
-    PolygonParams,
-    Polygons,
-    RenameLayerRequest,
+    ListPolygonsResponse,
+    ReplacePolygonsRequest,
     ShareLayerRequest,
     UpdatePolygonRequest,
 )
 
 __all__ = (
+    'Layer',
+    'Polygon',
     'AddPolygonRequest',
-    'BatchPolygonsRequest',
+    'BatchAddPolygonsRequest',
+    'BatchAddPolygonsResponse',
     'CopyLayerRequest',
     'CreateLayerRequest',
     'DeleteLayerRequest',
     'DeletePolygonRequest',
     'DropPolygonsRequest',
-    'EmptyParams',
-    'EmptyResponse',
     'GetLayerRequest',
-    'Layer',
-    'Layers',
+    'ListLayersRequest',
+    'ListLayersResponse',
     'ListPolygonsRequest',
-    'Polygon',
-    'PolygonParams',
-    'Polygons',
-    'RenameLayerRequest',
+    'ListPolygonsResponse',
+    'ReplacePolygonsRequest',
     'ShareLayerRequest',
     'UpdatePolygonRequest',
 )
