@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,8 @@
 from oceanbolt.com.portcalls_v3.services.port_call_service.client import PortCallServiceClient
 from oceanbolt.com.portcalls_v3.services.port_call_service.async_client import PortCallServiceAsyncClient
 
+from oceanbolt.com.portcalls_v3.types.service import AnchorageStay
+from oceanbolt.com.portcalls_v3.types.service import BerthStay
 from oceanbolt.com.portcalls_v3.types.service import EmptyParams
 from oceanbolt.com.portcalls_v3.types.service import EmptyResponse
 from oceanbolt.com.portcalls_v3.types.service import GetPortCallsRequest
@@ -24,13 +26,18 @@ from oceanbolt.com.portcalls_v3.types.service import GetPortCallsResponse
 from oceanbolt.com.portcalls_v3.types.service import GetPortCallTimeseriesResponse
 from oceanbolt.com.portcalls_v3.types.service import GetPortParticularsRequest
 from oceanbolt.com.portcalls_v3.types.service import GetPortParticularsResponse
+from oceanbolt.com.portcalls_v3.types.service import GetVesselsInPortRequest
+from oceanbolt.com.portcalls_v3.types.service import GetVesselsInPortResponse
 from oceanbolt.com.portcalls_v3.types.service import PortCall
 from oceanbolt.com.portcalls_v3.types.service import Statistic
 from oceanbolt.com.portcalls_v3.types.service import TimeseriesGroup
 from oceanbolt.com.portcalls_v3.types.service import TimeseriesRow
+from oceanbolt.com.portcalls_v3.types.service import VesselInPort
 
 __all__ = ('PortCallServiceClient',
     'PortCallServiceAsyncClient',
+    'AnchorageStay',
+    'BerthStay',
     'EmptyParams',
     'EmptyResponse',
     'GetPortCallsRequest',
@@ -38,8 +45,11 @@ __all__ = ('PortCallServiceClient',
     'GetPortCallTimeseriesResponse',
     'GetPortParticularsRequest',
     'GetPortParticularsResponse',
+    'GetVesselsInPortRequest',
+    'GetVesselsInPortResponse',
     'PortCall',
     'Statistic',
     'TimeseriesGroup',
     'TimeseriesRow',
+    'VesselInPort',
 )
